import { BigNumber } from 'bignumber.js';
import { IBigNumber, IBigNumberRoundingModeName, IBigNumberRoundingMode, IBigNumberValue, IBigNumberFormat, IType, IConfig, IBigNumberToType, IOutput } from './shared/types.js';
/**
 * Instantiates BigNumber from a valid numeric value.
 * @param value
 * @returns IBigNumber
 * @throws
 * - INVALID_VALUE: if the given value is NaN (not a number) or BigNumber throws an error
 */
declare const getBigNumber: (value: IBigNumberValue) => IBigNumber;
/**
 * Processes and outputs a value to match the requirements specified in the configuration (if any).
 * @param value
 * @param configuration?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if the given value is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 */
declare const processValue: <T extends Partial<IConfig>>(value: IBigNumberValue, configuration?: T) => IOutput<T>;
/**
 * Generates the string representation of a value after being processed and formatted to match the
 * requirements specified in the configuration (if any).
 * @param value
 * @param config?
 * @returns string
 * @throws
 * - INVALID_VALUE: if the given value is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - INVALID_BIGNUMBER_FORMAT: if any of the format properties are invalid
 */
declare const prettifyValue: (value: IBigNumberValue, config?: {
    processing?: Partial<IConfig>;
    format?: Partial<IBigNumberFormat>;
}) => string;
/**
 * Verifies if the value is a BigNumber Instance.
 * @param value
 * @returns boolean
 */
declare const isBigNumber: (value: any) => value is BigNumber;
/**
 * Verifies if the value is a number in any of the supported types (IBigNumberValue).
 * @param value
 * @returns boolean
 */
declare const isNumber: (value: any) => value is number;
/**
 * Verifies if the value is an integer in any of the supported types (IBigNumberValue).
 * @param value
 * @returns boolean
 */
declare const isInteger: (value: any) => value is number;
/**
 * Verifies if the value is a float in any of the supported types (IBigNumberValue).
 * @param value
 * @returns boolean
 */
declare const isFloat: (value: any) => value is number;
/**
 * Calculates the sum for an array of values. It returns 0 if the array is empty.
 * @param values
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - INVALID_VALUES_ARRAY: if the provided values arg is not a valid array
 */
declare const calculateSum: <T extends Partial<IConfig>>(values: IBigNumberValue[], config?: T) => IOutput<T>;
/**
 * Identifies the smallest value in an array. It returns 0 if the array is empty.
 * @param values
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - INVALID_VALUES_ARRAY: if the provided values arg is not a valid array
 */
declare const calculateMin: <T extends Partial<IConfig>>(values: IBigNumberValue[], config?: T) => IOutput<T>;
/**
 * Identifies the largest value in an array. It returns 0 if the array is empty.
 * @param values
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - INVALID_VALUES_ARRAY: if the provided values arg is not a valid array
 */
declare const calculateMax: <T extends Partial<IConfig>>(values: IBigNumberValue[], config?: T) => IOutput<T>;
/**
 * Calculates the mean for an array of values. It returns 0 if the array is empty.
 * @param values
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - INVALID_VALUES_ARRAY: if the provided values arg is not a valid array
 */
declare const calculateMean: <T extends Partial<IConfig>>(values: IBigNumberValue[], config?: T) => IOutput<T>;
/**
 * Calculates the median for an array of values. It returns 0 if the array is empty.
 * @param values
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - INVALID_VALUES_ARRAY: if the provided values arg is not a valid array
 */
declare const calculateMedian: <T extends Partial<IConfig>>(values: IBigNumberValue[], config?: T) => IOutput<T>;
/**
 * Calculates the percentage change experienced by a value. Note that if the value increased, the
 * change will be positive. Otherwise, it will be negative. If there was no change, it returns 0.
 * Moreover, the largest decrease supported by this library is -100%. If newValue is less than or
 * equal to 0, -100 will be returned.
 * @param oldValue
 * @param newValue
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - NEGATIVE_VALUE_NOT_ALLOWED: if the oldValue is not positive
 */
declare const calculatePercentageChange: <T extends Partial<IConfig>>(oldValue: IBigNumberValue, newValue: IBigNumberValue, config?: T) => IOutput<T>;
/**
 * Changes a value by a percentage. If the % is positive, it increases the value. Otherwise, it
 * decreases it.
 * @param value
 * @param percentage
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - NEGATIVE_VALUE_NOT_ALLOWED: if the value is not positive
 */
declare const adjustByPercentage: <T extends Partial<IConfig>>(value: IBigNumberValue, percentage: IBigNumberValue, config?: T) => IOutput<T>;
/**
 * Calculates the percentage representation of a value based on a total.
 * @param value
 * @param total
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - NEGATIVE_VALUE_NOT_ALLOWED: if the value or total are not positive
 */
declare const calculatePercentageRepresentation: <T extends Partial<IConfig>>(value: IBigNumberValue, total: IBigNumberValue, config?: T) => IOutput<T>;
/**
 * Calculates the asset amount that will be received once the exchange executes.
 * - Example: calculateExchange(value = 100 USDT, rate = 65000 USDT/BTC) => 0.00154 BTC
 * @param value
 * @param rate
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - NEGATIVE_VALUE_NOT_ALLOWED: if the value or rate are not positive
 */
declare const calculateExchange: <T extends Partial<IConfig>>(value: IBigNumberValue, rate: IBigNumberValue, config?: T) => IOutput<T>;
/**
 * Calculates the fee amount that will be charged when executing a currency exchange based on a
 * percentage.
 * @param value
 * @param feePercentage
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - NEGATIVE_VALUE_NOT_ALLOWED: if the value or feePercentage are not positive
 */
declare const calculateExchangeFee: <T extends Partial<IConfig>>(value: IBigNumberValue, feePercentage: IBigNumberValue, config?: T) => IOutput<T>;
/**
 * Calculates the weighted average trade price when a position can have several entries at different
 * prices for different amounts. If the array is empty, it returns 0.
 * Important: the trades' tuples must follow: [price, amount].
 * @param trades // Array<[price, amount]>
 * @param config?
 * @returns IOutput<T>
 * @throws
 * - INVALID_VALUE: if any of the given values is NaN (not a number) or BigNumber throws an error
 * - INVALID_DECIMAL_PLACES: if the number of decimal places is invalid for any reason
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 * - INVALID_TYPE: if the processing type is not supported
 * - INVALID_VALUES_ARRAY: if the provided values arg is not a valid array
 */
declare const calculateWeightedEntry: <T extends Partial<IConfig>>(trades: Array<[IBigNumberValue, IBigNumberValue]>, config?: T) => IOutput<T>;
export { type IBigNumber, type IBigNumberRoundingModeName, type IBigNumberRoundingMode, type IBigNumberValue, type IBigNumberFormat, type IType, type IConfig, type IBigNumberToType, type IOutput, getBigNumber, processValue, prettifyValue, isBigNumber, isNumber, isInteger, isFloat, calculateSum, calculateMin, calculateMax, calculateMean, calculateMedian, calculatePercentageChange, adjustByPercentage, calculatePercentageRepresentation, calculateExchange, calculateExchangeFee, calculateWeightedEntry, };
